dyPolyChord
===========

.. image:: https://travis-ci.org/ejhigson/dyPolyChord.svg?branch=master
    :target: https://travis-ci.org/ejhigson/dyPolyChord
.. image:: https://coveralls.io/repos/github/ejhigson/dyPolyChord/badge.svg?branch=master
    :target: https://coveralls.io/github/ejhigson/dyPolyChord?branch=master
.. image:: https://readthedocs.org/projects/dypolychord/badge/?version=latest
    :target: http://dypolychord.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://api.codeclimate.com/v1/badges/b04cc235c8f73870029c/maintainability
    :target: https://codeclimate.com/github/ejhigson/dyPolyChord/maintainability
    :alt: Maintainability
.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://github.com/ejhigson/dyPolyChord/LICENSE

+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Read the documentation at `http://dyPolyChord.readthedocs.io <http://dyPolyChord.readthedocs.io>`_.
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
